private library

Classes

Native
base class for all Native uses
NativeHandler
Private API for handling NativeWidgets.
NativeState<T extends NativeStatefulWidget>
The corresponding State class that implements the build method
NativeStatefulWidget
for custom implementations of StatefulWidget
NativeStatelessWidget
for custom implementations of StatelessWidget
NativeWidget
for custom implementations of Widget

Functions

getBrightness(BuildContext context) Brightness
Private API to get the current Brightness (light or dark). It uses a method that is Cupertino-compliant.
getFont() String
Private API to get the current Design's font.
getPlatform() String
Private API to get the platform, while having safety for web platforms.
print(dynamic input, {String? code, bool bold = false, String? color}) → void
warn(dynamic input, {String? code, bool bold = false, String? color = "\x1B[33m"}) → void

Exceptions / Errors

DesignOverflowError