NativeTextTheme class
Constructors
- NativeTextTheme({Type type = TextTheme, TextStyle? displayLarge, TextStyle? displayMedium, TextStyle? displaySmall, TextStyle? headlineLarge, TextStyle? headlineMedium, TextStyle? headlineSmall, TextStyle? titleLarge, TextStyle? titleMedium, TextStyle? titleSmall, TextStyle? bodyLarge, TextStyle? bodyMedium, TextStyle? bodySmall, TextStyle? labelLarge, TextStyle? labelMedium, TextStyle? labelSmall, Color color = Colors.red, TextStyle? bodyStrong})
-
Constructor for NativeTextTheme
const
Properties
- bodyLarge → TextStyle?
-
final
- bodyMedium → TextStyle?
-
final
- bodySmall → TextStyle?
-
final
- bodyStrong → TextStyle?
-
final
- color → Color
-
final
- displayLarge → TextStyle?
-
final
- displayMedium → TextStyle?
-
final
- displaySmall → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlineLarge → TextStyle?
-
final
- headlineMedium → TextStyle?
-
final
- headlineSmall → TextStyle?
-
final
- labelLarge → TextStyle?
-
final
- labelMedium → TextStyle?
-
final
- labelSmall → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleLarge → TextStyle?
-
final
- titleMedium → TextStyle?
-
final
- titleSmall → TextStyle?
-
final
- type → Type
-
Material equivalent
finalinherited
Methods
-
build(
BuildContext context) → dynamic -
builder
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited