NativeIcon class
Returns an icon Widget depending on the platform:
macOS: MacosIcon Everything else: a normal Icon
Note: it is recommended to only use NativeIconData with NativeIcon. Because of the way the macos_ui library is built, NativeIconData returns a Material Icon for the macOS style. NativeIcon uses the MacosIcon Widget with the Material Icon it receives, thus making it a macOS-styled icon.
- Inheritance
Constructors
-
NativeIcon(NativeIconData icon, {Key? key, Type type = Icon, bool disableWarnings = kDebugMode, double? size, double? fill, double? weight, double? grade, double? opticalSize, Color? color, List<
Shadow> ? shadows, String? semanticLabel, TextDirection? textDirection, bool? applyTextScaling, BlendMode? blendMode}) -
const
Properties
- applyTextScaling → bool?
-
final
- blendMode → BlendMode?
-
final
- color → Color?
-
final
- disableWarnings → bool
-
final
- fill → double?
-
final
- grade → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → NativeIconData
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- opticalSize → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
-
shadows
→ List<
Shadow> ? -
final
- size → double?
-
final
- textDirection → TextDirection?
-
final
- type → Type
-
Material equivalent
finalinherited
- weight → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited