NativeIconData constructor

const NativeIconData({
  1. bool disableWarnings = kDebugMode,
  2. IconData? icon,
  3. IconData? cupertinoIcon,
  4. IconData? fluentIcon,
  5. IconData? yaruIcon,
  6. IconData? macosIcon,
  7. IconData fallback = Icons.warning_amber,
})

Implementation

const NativeIconData({
  this.disableWarnings = kDebugMode,
  this.icon,
  this.cupertinoIcon,
  this.fluentIcon,
  this.yaruIcon,

  /// macosIcon is not strictly required due to the fact that the macos_ui library uses a specialized Widget that relies on the regular Material Icons library to generate a macOS icon. Because of this, you can omit the macosIcon argument, as it will just use the icon parameter.
  this.macosIcon,

  /// If you see a random warning symbol in your code, then that means that you didn't supply an icon for the platform the app is currently running on. That's why it's recommended to fill out It is recommended to fill out icon, cupertinoIcon, fluentIcon, and yaruIcon. (see macosIcon docs for details of why macosIcon isn't required)
  this.fallback = Icons.warning_amber,
});