NativeThemeData class
Allows you to create theme data based on the platform:
Android/
Constructors
-
NativeThemeData({required BuildContext context, Iterable<
Adaptation< ? adaptations, bool? applyElevationOverlayColor, NoDefaultCupertinoThemeData? cupertinoOverrideTheme, Iterable<Object> >ThemeExtension< ? extensions, InputDecorationTheme? inputDecorationTheme, MaterialTapTargetSize? materialTapTargetSize, PageTransitionsTheme? pageTransitionsTheme, TargetPlatform? platform, ScrollbarThemeData? scrollbarTheme, InteractiveInkFeatureFactory? splashFactory, bool? useMaterial3, VisualDensity? visualDensity, ColorScheme? colorScheme, Brightness? brightness, Color? colorSchemeSeed, Color? canvasColor, Color? cardColor, Color? dialogBackgroundColor, Color? disabledColor, Color? dividerColor, Color? focusColor, Color? highlightColor, Color? hintColor, Color? hoverColor, Color? indicatorColor, Color? primaryColor, Color? primaryColorDark, Color? primaryColorLight, MaterialColor? primarySwatch, Color? secondaryHeaderColor, Color? shadowColor, Color? splashColor, Color? unselectedWidgetColor, String? fontFamily, List<ThemeExtension> >String> ? fontFamilyFallback, String? package, IconThemeData? iconTheme, IconThemeData? primaryIconTheme, NativeTextTheme? primaryTextTheme, NativeTextTheme? textTheme, NativeTypography? typography, ActionIconThemeData? actionIconTheme, AppBarTheme? appBarTheme, BadgeThemeData? badgeTheme, MaterialBannerThemeData? bannerTheme, BottomAppBarTheme? bottomAppBarTheme, BottomSheetThemeData? bottomSheetTheme, ButtonThemeData? buttonTheme, Object? cardTheme, CheckboxThemeData? checkboxTheme, ChipThemeData? chipTheme, DataTableThemeData? dataTableTheme, DatePickerThemeData? datePickerTheme, Object? dialogTheme, DividerThemeData? dividerTheme, DrawerThemeData? drawerTheme, DropdownMenuThemeData? dropdownMenuTheme, ElevatedButtonThemeData? elevatedButtonTheme, ExpansionTileThemeData? expansionTileTheme, FilledButtonThemeData? filledButtonTheme, FloatingActionButtonThemeData? floatingActionButtonTheme, IconButtonThemeData? iconButtonTheme, ListTileThemeData? listTileTheme, OutlinedButtonThemeData? outlinedButtonTheme, PopupMenuThemeData? popupMenuTheme, ProgressIndicatorThemeData? progressIndicatorTheme, RadioThemeData? radioTheme, SearchBarThemeData? searchBarTheme, SearchViewThemeData? searchViewTheme, SegmentedButtonThemeData? segmentedButtonTheme, SliderThemeData? sliderTheme, SnackBarThemeData? snackBarTheme, SwitchThemeData? switchTheme, Object? tabBarTheme, TextButtonThemeData? textButtonTheme, TextSelectionThemeData? textSelectionTheme, TimePickerThemeData? timePickerTheme, ToggleButtonsThemeData? toggleButtonsTheme, TooltipThemeData? tooltipTheme, ButtonBarThemeData? buttonBarTheme, bool? applyThemeToAll})
Properties
- actionIconTheme → ActionIconThemeData?
-
final
-
adaptations
→ Iterable<
Adaptation< ?Object> > -
final
- appBarTheme → AppBarTheme?
-
final
- applyElevationOverlayColor → bool?
-
final
- applyThemeToAll → bool?
-
final
- badgeTheme → BadgeThemeData?
-
final
-
final
- bottomAppBarTheme → BottomAppBarTheme?
-
final
-
final
- bottomSheetTheme → BottomSheetThemeData?
-
final
- brightness ↔ Brightness?
-
getter/setter pair
-
final
-
final
- canvasColor → Color?
-
final
- cardColor → Color?
-
final
- cardTheme → Object?
-
final
- checkboxTheme → CheckboxThemeData?
-
final
- chipTheme → ChipThemeData?
-
final
- colorScheme → ColorScheme?
-
final
- colorSchemeSeed → Color?
-
final
- context → BuildContext
-
final
- cupertinoOverrideTheme → NoDefaultCupertinoThemeData?
-
final
- dataTableTheme → DataTableThemeData?
-
final
- datePickerTheme → DatePickerThemeData?
-
final
- dialogBackgroundColor → Color?
-
final
- dialogTheme → Object?
-
final
- disabledColor → Color?
-
final
- dividerColor → Color?
-
final
- dividerTheme → DividerThemeData?
-
final
- drawerTheme → DrawerThemeData?
-
final
- dropdownMenuTheme → DropdownMenuThemeData?
-
final
- elevatedButtonTheme → ElevatedButtonThemeData?
-
final
- expansionTileTheme → ExpansionTileThemeData?
-
final
-
extensions
→ Iterable<
ThemeExtension< ?ThemeExtension> > -
final
- filledButtonTheme → FilledButtonThemeData?
-
final
- floatingActionButtonTheme → FloatingActionButtonThemeData?
-
final
- focusColor → Color?
-
final
- fontFamily → String?
-
final
-
fontFamilyFallback
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightColor → Color?
-
final
- hintColor → Color?
-
final
- hoverColor → Color?
-
final
- iconButtonTheme → IconButtonThemeData?
-
final
- iconTheme → IconThemeData?
-
final
- indicatorColor → Color?
-
final
- inputDecorationTheme → InputDecorationTheme?
-
final
- listTileTheme → ListTileThemeData?
-
final
- materialTapTargetSize → MaterialTapTargetSize?
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- outlinedButtonTheme → OutlinedButtonThemeData?
-
final
- package → String?
-
final
- pageTransitionsTheme → PageTransitionsTheme?
-
final
- platform → TargetPlatform?
-
final
- popupMenuTheme → PopupMenuThemeData?
-
final
- primaryColor → Color?
-
final
- primaryColorDark → Color?
-
final
- primaryColorLight → Color?
-
final
- primaryIconTheme → IconThemeData?
-
final
- primarySwatch → MaterialColor?
-
final
- primaryTextTheme → NativeTextTheme?
-
final
- progressIndicatorTheme → ProgressIndicatorThemeData?
-
final
- radioTheme → RadioThemeData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollbarTheme → ScrollbarThemeData?
-
final
- searchBarTheme → SearchBarThemeData?
-
final
- searchViewTheme → SearchViewThemeData?
-
final
- secondaryHeaderColor → Color?
-
final
- segmentedButtonTheme → SegmentedButtonThemeData?
-
final
- shadowColor → Color?
-
final
- sliderTheme → SliderThemeData?
-
final
- snackBarTheme → SnackBarThemeData?
-
final
- splashColor → Color?
-
final
- splashFactory → InteractiveInkFeatureFactory?
-
final
- switchTheme → SwitchThemeData?
-
final
- tabBarTheme → Object?
-
final
- textButtonTheme → TextButtonThemeData?
-
final
- textSelectionTheme → TextSelectionThemeData?
-
final
- textTheme → NativeTextTheme?
-
final
- timePickerTheme → TimePickerThemeData?
-
final
- toggleButtonsTheme → ToggleButtonsThemeData?
-
final
- tooltipTheme → TooltipThemeData?
-
final
- typography → NativeTypography?
-
final
- unselectedWidgetColor → Color?
-
final
- useMaterial3 → bool?
-
final
- visualDensity → VisualDensity?
-
final
Methods
-
build(
) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited