NativeTypography class
Constructors
- NativeTypography({Type type = Typography, TargetPlatform? platform, TextTheme? black, TextTheme? white, TextTheme? englishLike, TextTheme? dense, TextTheme? tall, TextStyle? displayLarge, TextStyle? displayMedium, TextStyle? displaySmall, TextStyle? headlineLarge, TextStyle? headlineMedium, TextStyle? headlineSmall, TextStyle? titleLarge, TextStyle? titleMedium, TextStyle? titleSmall, TextStyle? bodyLarge, TextStyle? bodyMedium, TextStyle? bodySmall, TextStyle? labelLarge, TextStyle? labelMedium, TextStyle? labelSmall, Color color = Colors.red, TextStyle? bodyStrong})
-
Constructor for NativeTypography
const
Properties
- black → TextTheme?
-
final
- bodyLarge → TextStyle?
-
final
- bodyMedium → TextStyle?
-
final
- bodySmall → TextStyle?
-
final
- bodyStrong → TextStyle?
-
final
- color → Color
-
final
- dense → TextTheme?
-
final
- displayLarge → TextStyle?
-
final
- displayMedium → TextStyle?
-
final
- displaySmall → TextStyle?
-
final
- englishLike → TextTheme?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlineLarge → TextStyle?
-
final
- headlineMedium → TextStyle?
-
final
- headlineSmall → TextStyle?
-
final
- labelLarge → TextStyle?
-
final
- labelMedium → TextStyle?
-
final
- labelSmall → TextStyle?
-
final
- platform → TargetPlatform?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tall → TextTheme?
-
final
- titleLarge → TextStyle?
-
final
- titleMedium → TextStyle?
-
final
- titleSmall → TextStyle?
-
final
- type → Type
-
Material equivalent
finalinherited
- white → TextTheme?
-
final
Methods
-
build(
BuildContext context) → dynamic -
builder
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited