NativeIconData class
For generating IconData to be used with NativeIcon. This is recommended to only be used with NativeIcon, and if used with anything else (this only applies to macOS), then it will not look correct.
macosIcon is not strictly required due to the fact that the macos_ui library uses a specialized Widget that relies on the regular Material Icons library to generate a macOS icon. Because of this, you can omit the macosIcon argument, as it will just use the icon parameter.
Constructors
Properties
- cupertinoIcon → IconData?
-
final
- disableWarnings → bool
-
final
- fallback → IconData
-
final
- fluentIcon → IconData?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- macosIcon → IconData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- yaruIcon → IconData?
-
final
Methods
-
build(
) → IconData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited