NativeNavItem class
Used for building navigation bar items. These are used anywhere from QuickNavBar (from my other package, quick_navbar) to MacosSidebar (from macos_ui).
Constructors
- NativeNavItem builder
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ NativeIcon
-
Icon
getter/setter pair
- label ↔ String?
-
Name
getter/setter pair
- onPressed ↔ Function?
-
Function to be ran when the nav item is pressed
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIcon ↔ NativeIcon?
-
Icon shown when selected
getter/setter pair
- widget ↔ Widget?
-
Corresponding page
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited